@@ -99,7 +99,9 @@ int interv(double *xt, int *lxt, double *x, int *left, int *mflag);
 
 double ppvalu(double *break_, double *coef, int *l, int *k, double *x, int *jderiv);
 
-int tautsp(double *x, double *y, unsigned int *n, double *gamma, double *scrtch, double *break_, double *coef, int *l, int *k, int *iflag);
+int tautsp(double *x, double *y, unsigned int n, double *gamma, double *scrtch, double *break_, double *coef, int *l, int *k, int *iflag);
+
+
 
 
 #if 0
@@ -615,18 +617,28 @@ double ppvalu(double *break_,
 }
 
 // Use iflag to indicate if call was ok
-int tautsp(double *tau,		// input data, x, of length ntau
-	   double *gtau,		// input data, y, of length ntau
-	   unsigned int *ntau,		// number data
-	   double *gamma,	// tension parameter
-	   double *s,		// length 6*ntau
-	   double *break_,	// knot locations, length=l
-	   double *coef,		// coefficients, length=4l
-	   int *l,		// returned # knots, max maybe 2*ntau
-	   int *k,		// always returned as 4
-	   int *iflag)		// 0 indicates call was ok
+
+#define SAVE    double *sORIG = s; double *break_ORIG = break_; double *coefORIG = coef; double *gtauORIG = gtau; double *tauORIG = tau;
+#define RESTORE s = sORIG; break_ = break_ORIG; coef = coefORIG; gtau = gtauORIG; tau = tauORIG;
+
+int
+tautsp(double *tau,		// input data, x, of length ntau
+       double *gtau,		// input data, y, of length ntau
+       unsigned int ntau,		// number data
+       double *gamma,	// tension parameter
+       double *s,		// length 6*ntau
+       double *break_,	// knot locations, length=l
+       double *coef,		// coefficients, length=4l
+       int *l,		// returned # knots, max maybe 2*ntau
+       int *k,		// always returned as 4
+       int *iflag)		// 0 indicates call was ok
 {
+        // Kelley: save the original pointers because these will be FREEd in the 
+        // calling subroutine -- this is NOT included in the NR code!
+        SAVE;
+	
 	int s_dim1, s_offset;
+
 	double r_1, r_2, r_3;
 
 	// Local variables
@@ -639,13 +651,13 @@ int tautsp(double *tau,		// input data, x, of length ntau
 	static double onemzt, zt2, del, gam;
 
 	// Parameter adjustments
-	--tau;
-	--gtau;
-	s_dim1 = *ntau;
+	--tau;			// NEED TO PROTECT (see above)
+	--gtau;			// NEED TO PROTECT (see above)
+	s_dim1 = ntau;
 	s_offset = s_dim1 + 1;
-	s -= s_offset;
-	--break_;
-	coef -= 5;
+	s -= s_offset;		// NEED TO PROTECT (see above)
+	--break_;		// NEED TO PROTECT (see above)
+	coef -= 5;		// NEED TO PROTECT (see above)
 
 	// From  A PRACTICAL GUIDE TO SPLINES by C. de Boor
 	//  Constructs cubic spline interpolant to given data
@@ -728,14 +740,23 @@ int tautsp(double *tau,		// input data, x, of length ntau
 	//  which we solve by gauss elimination without pivoting.
 
 	// there must be at least 4  interpolation points.
-	if (*ntau < 4) {
+	if (ntau < 4) {
 		err("Need more than 3 data points");
 		*iflag = 2;
+		RESTORE;
 		return 0;
 	}
 	// construct delta tau and first and second (divided) differences of data
-	ntaum1 = *ntau - 1;
+	ntaum1 = ntau - 1;
 	for (i = 1; i <= ntaum1; ++i) {
+#if 0
+		printf("i=%d\n",i);
+		printf("gtau[i  ]= %lf\n", gtau[i]);
+		printf("gtau[i+1]= %lf\n", gtau[i+1]);
+		printf("s[1+s_dim1]= %lf\n", s[1+s_dim1]);
+		printf(" i+1+(s_dim1<<2)= %d\n", i+1+(s_dim1<<2));
+		printf("s[i+1+(s_dim1<<2)]= %lf\n", s[i+1+(s_dim1<<2)]);
+#endif
 		s[i + s_dim1] = tau[i + 1] - tau[i];
 		if (s[i + s_dim1] <= 0.) {
 			sprintf(_grTempString, "\
@@ -743,6 +764,7 @@ X data must be ordered and distinct.\n\
        Problem at x[%d]=%f and x[%d]=%f\n", i, tau[i], i+1, tau[i+1]);
 			err(_grTempString);
 			*iflag = 2;
+			RESTORE;
 			return 0;
 		}
 		s[i + 1 + (s_dim1 << 2)] = (gtau[i + 1] - gtau[i]) / s[i + s_dim1];
@@ -759,6 +781,10 @@ X data must be ordered and distinct.\n\
 	sixth = 1.0 / 6.0;
 	method = 2;
 	gam = *gamma;
+	
+
+	printf("DEBUG: gam = %f\n",gam);
+
 	if (gam <= 0.0) {
 		method = 1;
 	}
@@ -766,6 +792,7 @@ X data must be ordered and distinct.\n\
 		method = 3;
 		gam += -3.0;
 	}
+	printf("DEBUG: gam=%f  method=%d\n",gam,method);
 	onemg3 = 1.0 - gam / 3.0;
 	// ------ loop over i ------
  L10:
@@ -974,7 +1001,7 @@ X data must be ordered and distinct.\n\
 
 	//        ------ back substitution ------
 
-	s[*ntau + (s_dim1 << 2)] /= s[*ntau + (s_dim1 << 1)];
+	s[ntau + (s_dim1 << 2)] /= s[ntau + (s_dim1 << 1)];
 
 	do {
 		s[i + (s_dim1 << 2)] 
@@ -1061,13 +1088,9 @@ X data must be ordered and distinct.\n\
 		r_1 = onemzt, r_2 = r_1;
 		coef[(*l << 2) + 4] = coef[(*l - 1 << 2) + 4] + (1. - alpha) * 
 			6. * c / (s[i + s_dim1] * (r_2 * (r_1 * r_1)));
-		coef[(*l << 2) + 3] = coef[(*l - 1 << 2) + 3] + del * coef[(*l - 1 << 
-									    2) + 4];
-		coef[(*l << 2) + 2] = coef[(*l - 1 << 2) + 2] + del * (coef[(*l - 1 <<
-									     2) + 3] + del / 2. * coef[(*l - 1 << 2) + 4]);
-		coef[(*l << 2) + 1] = coef[(*l - 1 << 2) + 1] + del * (coef[(*l - 1 <<
-									     2) + 2] + del / 2. * (coef[(*l - 1 << 2) + 3] + del / 
-												   3. * coef[(*l - 1 << 2) + 4]));
+		coef[(*l << 2) + 3] = coef[(*l - 1 << 2) + 3] + del * coef[(*l - 1 << 2) + 4];
+		coef[(*l << 2) + 2] = coef[(*l - 1 << 2) + 2] + del * (coef[(*l - 1 << 2) + 3] + del / 2. * coef[(*l - 1 << 2) + 4]);
+		coef[(*l << 2) + 1] = coef[(*l - 1 << 2) + 1] + del * (coef[(*l - 1 << 2) + 2] + del / 2. * (coef[(*l - 1 << 2) + 3] + del / 3. * coef[(*l - 1 << 2) + 4]));
 		goto L68;
 	L65:
 		coef[(*l << 2) + 2] = divdif;
@@ -1077,18 +1100,21 @@ X data must be ordered and distinct.\n\
 		++(*l);
 		// L70:
 		break_[*l] = tau[i + 1];
-		if (*l > 1 + 2 * int(*ntau)) {
+		if (*l > 1 + 2 * int(ntau)) {
 			gr_error("Too many knots.  Kelley thought max was 2*n\n");
+			RESTORE;
 			return 0;		// not reached
 		}
 	}
 	--(*l);
 	*k = 4;
 	*iflag = 1;
+	RESTORE;
 	return 0;
 } // tautsp
-
-
+#undef SAVE
+#undef RESTORE
+
 // `convert columns to spline \[.gamma.\] \[.xmin. .xmax. .xinc.\]\'
 bool
 convert_col_to_splineCmd()
@@ -1119,6 +1145,9 @@ convert_col_to_splineCmd()
 		NUMBER_WORDS_ERROR;
 		return false;
 	}
+
+	printf("DEBUG: gamma= %f\n", gamma);
+
 	Require(xmax != xmin, err("Cannot have .xmin. equaling .xmax."));
 	Require(xinc != 0, err("Cannot have .xinc. equal to zero"));
 	Require(xmax > xmin, err("Cannot have .xmin. exceeding .xmax."));
@@ -1131,23 +1160,32 @@ convert_col_to_splineCmd()
 		return false;
 	}
 	// Get storage
+	unsigned int n = _colX.size(); // for tautsp
 	double *xs, *ys, *coef, *break_point, *scrtch;
 	xs = ys = coef = break_point = scrtch = (double*)NULL;
+#if 0
 	GET_STORAGE(xs, double, (size_t)steps);
+	printf("DEBUG %s:%d: got xs     storage at %x\n",__FILE__,__LINE__,int(xs));
 	GET_STORAGE(ys, double, (size_t)steps);
+	printf("DEBUG %s:%d: got ys     storage at %x\n",__FILE__,__LINE__,int(ys));
 	GET_STORAGE(coef, double, (size_t)(4 * 2 * steps));
+	printf("DEBUG %s:%d: got coef   storage at %x\n",__FILE__,__LINE__,int(coef));
 	GET_STORAGE(break_point, double, (size_t)(2 * steps));
-	GET_STORAGE(scrtch, double, (size_t)(6 * steps));
-	//std::vector<double> xs((size_t)steps, 0.0);
-	//std::vector<double> ys((size_t)steps, 0.0);
-	//std::vector<double> coef((size_t)(4 * 2 * steps), 0.0);
-	//std::vector<double> break_point((size_t)(2 * steps), 0.0);
-	//std::vector<double> scrtch((size_t)(6 * steps), 0.0);
-	unsigned int n = _colX.size();
+	printf("DEBUG %s:%d: got break_point storage at %x\n",__FILE__,__LINE__,int(break_point));
+	GET_STORAGE(scrtch, double, (size_t)(6 * steps)); // BUG: is this enough storage??
+	printf("DEBUG %s:%d: got scrtch storage (%d elements) at %x\n",__FILE__,__LINE__,(6*steps),int(scrtch));
+#else
+	GET_STORAGE(coef, double, (size_t)(4 * 2 * n));
+	//printf("DEBUG %s:%d: got coef   storage at %x\n",__FILE__,__LINE__,int(coef));
+	GET_STORAGE(break_point, double, (size_t)(2 * n));
+	//printf("DEBUG %s:%d: got break_point storage at %x\n",__FILE__,__LINE__,int(break_point));
+	GET_STORAGE(scrtch, double, (size_t)(6 * n)); // BUG: is this enough storage??
+	//printf("DEBUG %s:%d: got scrtch storage (%d elements) at %x\n",__FILE__,__LINE__,(6*n),int(scrtch));
+#endif
 	int l, k, iflag;
 	tautsp(_colX.begin(),
 	       _colY.begin(),
-	       &n,
+	       n,
 	       &gamma,
 	       scrtch,
 	       break_point,
@@ -1156,6 +1194,10 @@ convert_col_to_splineCmd()
 	       &k,
 	       &iflag);
 	int zero = 0;
+	GET_STORAGE(xs, double, (size_t)steps);
+	//printf("DEBUG %s:%d: got xs     storage at %x\n",__FILE__,__LINE__,int(xs));
+	GET_STORAGE(ys, double, (size_t)steps);
+	//printf("DEBUG %s:%d: got ys     storage at %x\n",__FILE__,__LINE__,int(ys));
 	for (unsigned int i = 0; i < (unsigned int)steps; i++) {
 		xs[i] = xmin + i * xinc;
 		ys[i] = ppvalu(break_point, coef, &l, &k, &xs[i], &zero);
@@ -1167,11 +1209,17 @@ convert_col_to_splineCmd()
 		_colX[i] = xs[i];
 		_colY[i] = ys[i];
 	}
+	//printf("DEBUG %s:%d: about to free xs at %x\n",__FILE__,__LINE__,int(xs));
 	free(xs);
+	//printf("DEBUG %s:%d: about to free ys at %x\n",__FILE__,__LINE__,int(ys));
 	free(ys);
+	//printf("DEBUG %s:%d: about to free coef at %x\n",__FILE__,__LINE__,int(coef));
 	free(coef);
+	//printf("DEBUG %s:%d: about to free break_point at %x\n",__FILE__,__LINE__,int(break_point));
 	free(break_point);
+	//printf("DEBUG %s:%d: about to free scrtch at %x\n",__FILE__,__LINE__,int(scrtch));
 	free(scrtch);
+	//printf("DEBUG %s:%d ... after the free of scrtch\n",__FILE__,__LINE__);
 	return true;
 }
 
