@@ -136,8 +136,9 @@ gr_drawimage(unsigned char *im,
 		jlow =  int(floor(0.5 + (_clip_ps_ybottom - yb)*jmax/((yt-yb))));
 		jhigh = int(floor(0.5 + (_clip_ps_ytop    - yb)*jmax/((yt-yb))));
 
-		/*DEK*/printf("DEBUG: initially ilow,ihigh= %d %d      jlow,jhigh=%d %d\n",ilow,ihigh,jlow,jhigh);
-
+#if 0
+//		printf("DEBUG: initially ilow,ihigh= %d %d      jlow,jhigh=%d %d\n",ilow,ihigh,jlow,jhigh);
+#endif
 		ilow = LARGER_ONE(ilow, 0);
 		ihigh = SMALLER_ONE(ihigh, imax);
 		jlow = LARGER_ONE(jlow, 0);
@@ -245,7 +246,7 @@ gr_drawimage(unsigned char *im,
 			 */
 			if (imTransform != NULL) {
 				for (i = 0; i < 256; i++) {
-					diff = (int) fabs(imTransform[i] - mask_value);
+					diff = (int) fabs(double(imTransform[i] - mask_value));
 					if (diff < min_diff) {
 						min_diff = diff;
 						index = i;
@@ -288,7 +289,7 @@ gr_drawimage(unsigned char *im,
 			fprintf(_grPS, "%%BEGIN_IMAGE\n");
 		fprintf(_grPS, "%f %f %f %f %d %d cim\n", xl_c, yb_c, xr_c, yt_c, (jhigh-jlow), (ihigh-ilow)); // BUG
 		/*DEK*/
-		printf("DEBUG: ilow, ihigh = %d %d      jlow, jhigh = %d %d\n",ilow,ihigh,jlow,jhigh);
+//		printf("DEBUG: ilow, ihigh = %d %d      jlow, jhigh = %d %d\n",ilow,ihigh,jlow,jhigh);
 
 		check_psfile();
 #if 0
