@@ -150,6 +150,8 @@ last_name(char *s)
 bool
 start_up(int argc, char **argv)
 {
+	extern rectangle _page_size;
+	_page_size.set(0.0, 0.0, 0.0, 0.0);
 /*
 #if defined(TEST_POPT)
 	printf("DEBUG: %s:%d: FYI, start_up() found the raw args to be:\n",__FILE__,__LINE__);
@@ -320,8 +322,6 @@ first argument looks like a PostScript filename.  Older versions\n\
 
 	_first = true;
 	_bounding_box.set(0.0, 0.0, 0.0, 0.0);
-	extern rectangle _page_size;
-	_page_size.set(0.0, 0.0, 0.0, 0.0);
 	//printf("At end of start_up, _cmdLine is <%s>\n",_cmdLine);
 	return true;
 }
@@ -509,14 +509,18 @@ set_defaults()
 	_grid_exists = false;
 	_xgrid_exists = false;
 	_ygrid_exists = false;
-	gr_setmissingvalue(MISSING_VALUE);
+	// 
+	gr_set_missing_value(MISSING_VALUE);
 	PUT_VAR("..missingvalue..", gr_currentmissingvalue());
 	{
 		char tmp[100];
 		sprintf(tmp, "%f", gr_currentmissingvalue());
 		put_syn("\\.missingvalue.", tmp, true);
 	}
-	_f_min = _f_max = gr_currentmissingvalue();	// no grid data
+	_f_min = _f_max = gr_currentmissingvalue();	// BUG: what if not using missing values?
+#if 1				// version > 2.12.7
+	gr_set_missing_value_none();
+#endif
 	_need_x_axis = true;
 	_need_y_axis = true;
 	_num_xmatrix_data = 0;
@@ -765,8 +769,11 @@ interpret_optional_arguments(int argc, char *argv[])
 						fatal_err("Cannot open SVG file named `\\", o.c_str(), "'", "\\");
 					}
 					fprintf(_grSVG, "<?xml version=\"1.0\" standalone=\"yes\"?>\n");
-					fprintf(stderr, "%s:%d: SVG error: assuming height and width both 500 pixels, for now\n", __FILE__,__LINE__);
-					fprintf(_grSVG, "<svg width=\"500\" height=\"500\">\n");
+					//fprintf(stderr, "%s:%d: SVG error: assuming height and width both 500 pixels, for now\n", __FILE__,__LINE__);
+					extern rectangle _page_size;
+					_page_size.set(0.0, 0.0, 8.5, 11.0); // BUG: SVG setting fixed paper size
+					_page_size.scale(CM_PER_IN);
+					fprintf(_grSVG, "<svg width=\"%d\" height=\"%d\">\n", int(8.5*PT_PER_IN), int(11.0*PT_PER_IN));
 				} else {
 					warning("Sorry, cannot determine type of output file; using default postscript filename instead");
 				}
@@ -931,16 +938,18 @@ interpret_optional_arguments(int argc, char *argv[])
 								_output_file_type = gif;
 							} else if (strEQ(o.c_str() + suffix_index, ".svg")) {
 								extern FILE *_grSVG;
-								fprintf(stderr, "%s:%d: SVG output to file '%s' does not work yet\n", __FILE__,__LINE__, o.c_str());
+								fprintf(stderr, "%s:%d: warning: SVG output is rudimentary.  Note the warnings below.\n\tAlso, the following fail completely:\n\t\tfilled curves\n\t\timages\n\t\t...\n", __FILE__,__LINE__);
 								_output_file_type = svg;
 								_grSVG = fopen(o.c_str(), "w");
 								if (!_grSVG) {
 									fatal_err("Cannot open SVG file named `\\", o.c_str(), "'", "\\");
 								}
 								fprintf(_grSVG, "<?xml version=\"1.0\" standalone=\"yes\"?>\n");
-								fprintf(stderr, "%s:%d: SVG error: assuming height and width both 500 pixels, for now\n", __FILE__,__LINE__);
-								fprintf(_grSVG, "<svg width=\"500\" height=\"500\">\n");
-
+								//fprintf(stderr, "%s:%d: SVG error: assuming height and width both 500 pixels, for now\n", __FILE__,__LINE__);
+								extern rectangle _page_size;
+								_page_size.set(0.0, 0.0, 8.5, 11.0); // BUG: SVG setting fixed paper size
+								_page_size.scale(CM_PER_IN);
+								fprintf(_grSVG, "<svg width=\"%d\" height=\"%d\">\n", int(8.5*PT_PER_IN), int(11.0*PT_PER_IN));
 							} else {
 								warning("Sorry, cannot determine type of output file; using default postscript filename instead");
 							}
